@@ -18,7 +18,6 @@ class MAGETorchPolicy(ModelTrainingMixin, EnvFnMixin, SOPTorchPolicy):
         loss_critic: model-based action-value-gradient estimator loss
     """
 
-    # pylint:disable=abstract-method
     dist_class = WrapDeterministicPolicy
 
     def __init__(self, observation_space, action_space, config):
@@ -44,6 +43,10 @@ class MAGETorchPolicy(ModelTrainingMixin, EnvFnMixin, SOPTorchPolicy):
 
         return MAGETrainer.options
 
+    @property
+    def model_training_loss(self):
+        return self.loss_model
+
     def compile(self):
         super().compile()
         for loss in (self.loss_model, self.loss_actor, self.loss_critic):
