@@ -11,7 +11,7 @@ from .policy import DAPOTorchPolicy
 @trainer.option("losses/", help="Configurations for actor loss function")
 @trainer.option(
     "losses/grad_estimator",
-    "PD",
+    default="PD",
     help="""Gradient estimator for optimizing expectations.
 
     Possible types include
@@ -21,11 +21,11 @@ from .policy import DAPOTorchPolicy
 )
 @trainer.option(
     "losses/model_samples",
-    4,
+    default=1,
     help="Number of next states to sample from the model when calculating the"
     " model-aware deterministic policy gradient",
 )
-@trainer.option("module/type", "SAC")
+@trainer.option("module/type", default="SAC")
 @sac_config
 class DAPOTrainer(OffPolicyTrainer):
     """Single-agent trainer for Dynamics-Aware Policy Optimization"""
