@@ -13,7 +13,7 @@ class MBPOTorchPolicy(
 ):
     """Model-Based Policy Optimization policy in PyTorch to use with RLlib."""
 
-    # pylint:disable=abstract-method,too-many-ancestors
+    # pylint:disable=too-many-ancestors
     dist_class = WrapStochasticPolicy
 
     def __init__(self, observation_space, action_space, config):
@@ -28,6 +28,10 @@ class MBPOTorchPolicy(
 
         return MBPOTrainer.options
 
+    @property
+    def model_training_loss(self):
+        return self.loss_model
+
     def _make_optimizers(self):
         optimizers = super()._make_optimizers()
         config = self.config["torch_optimizer"]
